@@ -9,6 +9,8 @@ OC.L10N.register(
     "Details" : "Λεπτομέρειες",
     "Delete" : "Διαγραφή",
     "Saved" : "Αποθηκεύτηκε",
+    "Date added" : "Ημερομηνία Προσθήκης",
+    "Link" : "Σύνδεσμος",
     "Tags" : "Ετικέτες",
     "Description" : "Περιγραφή",
     "No bookmarks here." : "Δεν υπάρχουν σελιδοδείκτες εδώ",
@@ -16,19 +18,25 @@ OC.L10N.register(
     "Settings" : "Ρυθμίσεις",
     "Add to {instanceName} " : "Προσθήκη στο {instanceName} ",
     "Recently added" : "Προστέθηκαν πρόσφατα",
+    "List view" : "Προβολή λίστας",
     "RSS Feed" : "Ροή RSS",
+    "Permanently remove all bookmarks from your account. There is no going back!" : "Οριστική διαγραφή όλων των σελιδοδείκτων από το λογαριασμό σας. Δεν υπάρχει επιστροφή!",
+    "Delete all bookmarks" : "Διαγραφή όλων των σελιδοδείκτων",
     "Open details" : "Άνοιγμα λεπτομερειών",
     "An error occurred while trying to save the bookmark." : "Παρουσιάστηκε σφάλμα κατά την αποθήκευση του σελιδοδείκτη",
     "Error" : "Σφάλμα",
     "Uncategorized" : "Μή-κατηγοριοποιημένα",
+    "Do you really want to delete all your bookmarks?" : "Θέλετε σίγουρα να διαγράψετε όλους σας τους σελιδοδείκτες;",
     "Set tags" : "Ορισμός ετικετών",
     "Failed to import one bookmark, because: " : "Αποτυχία εισαγωγής ενός σελιδοδείκτη, επειδή:",
     "No file provided for import" : "Δεν δόθηκε αρχείο για εισαγωγή",
     "Unsupported file type for import" : "Μη υποστηριζόμενος τύπος αρχείου",
+    "A Bookmark manager for Nextcloud" : "Διαχειριστής σελιδοδείκτων του Nextcloud",
     "Add a bookmark" : "Προσθήκη σελιδοδείκτη",
     "The title of the page" : "Ο τίτλος της σελίδας",
     "The address of the page" : "Η διεύθυνση της σελίδας",
     "Description of the page" : "Περιγραφή της σελίδας",
-    "Save" : "Αποθήκευση"
+    "Save" : "Αποθήκευση",
+    "Previews" : "Προεπισκοπήσεις"
 },
 "nplurals=2; plural=(n != 1);");
